# Lab library

## LIP6

```{eval-rst}
.. automodule:: gismap.lab_examples.lip6
    :members:
```

## Toulouse

```{eval-rst}
.. automodule:: gismap.lab_examples.toulouse
    :members:
```

## LINCS

```{eval-rst}
.. automodule:: gismap.lab_examples.lincs
    :members:
```
